# Lingua Franca Base

This package contains the following two modules:

functions.py which contains some useful functions used in Lingua Franca programs
constants.py which contains handy shortcuts for some concepts such as 'interval_t'


This package is required for Python generated code to function properly.
To build and install, run:

    python3 setup.py build
    sudo python3 setup.py install
